==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GtkToolkit__24LRUCache.h <==
// class gnu.java.awt.peer.gtk.GtkToolkit$LRUCache

// class file dependencies
// @dep_class e95ddd8096bf91ca gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c7382c60132d0b2c java_util_AbstractMap
// @dep_class d7cd853200c3e71f java_util_HashMap
// @dep_class 2c839a8260baa57f java_util_LinkedHashMap

// header file dependencies
// @dep_header java_util_LinkedHashMap

#include "java/util/LinkedHashMap.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache_H_
#define _JC_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache_H_

// Forward structure declarations
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map__24Entry$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$refs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$object	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vmethods	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vtable	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vtype	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$method$_init$8b59fde4178922fe(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$object *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit$object *, jint);

// Virtual methods
extern jboolean _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$method$removeEldestEntry$c2aa6e9c82650f0c(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$method_info$removeEldestEntry$c2aa6e9c82650f0c;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vmethods {
	jboolean	(*removeEldestEntry$c2aa6e9c82650f0c)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap$vmethods	java_util_AbstractMap;
	_jc_java_util_HashMap$vmethods	java_util_HashMap;
	_jc_java_util_LinkedHashMap$vmethods	java_util_LinkedHashMap;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vmethods	gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$sub_refs {
	struct _jc_gnu_java_awt_peer_gtk_GtkToolkit$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$refs {
    _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$sub_refs	gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache;
    _jc_java_util_LinkedHashMap$sub_refs	java_util_LinkedHashMap;
    _jc_java_util_HashMap$sub_refs	java_util_HashMap;
    _jc_java_util_AbstractMap$sub_refs	java_util_AbstractMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$sub_nonrefs {
	jint	max__5fentries;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap$sub_nonrefs	java_util_AbstractMap;
    _jc_java_util_HashMap$sub_nonrefs	java_util_HashMap;
    _jc_java_util_LinkedHashMap$sub_nonrefs	java_util_LinkedHashMap;
    _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$sub_nonrefs	gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$object {
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vtype _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache_H_ */

==> jc-1.4.5.tar.gz: gnu/java/awt/peer/gtk/GtkToolkit__24LRUCache.h <==
// class gnu.java.awt.peer.gtk.GtkToolkit$LRUCache

// class file dependencies
// @dep_class e95ddd8096bf91ca gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c7382c60132d0b2c java_util_AbstractMap
// @dep_class d7cd853200c3e71f java_util_HashMap
// @dep_class 2c839a8260baa57f java_util_LinkedHashMap

// header file dependencies
// @dep_header java_util_LinkedHashMap

#include "java/util/LinkedHashMap.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache_H_
#define _JC_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache_H_

// Forward structure declarations
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Map__24Entry$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$refs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$object	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vmethods	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vtable	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vtype	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$method$_init$8b59fde4178922fe(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$object *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$method$removeEldestEntry$c2aa6e9c82650f0c(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$method_info$removeEldestEntry$c2aa6e9c82650f0c;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vmethods {
	jboolean	(*removeEldestEntry$c2aa6e9c82650f0c)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap$vmethods	java_util_AbstractMap;
	_jc_java_util_HashMap$vmethods	java_util_HashMap;
	_jc_java_util_LinkedHashMap$vmethods	java_util_LinkedHashMap;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vmethods	gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$sub_refs {
	struct _jc_gnu_java_awt_peer_gtk_GtkToolkit$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$refs {
    _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$sub_refs	gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache;
    _jc_java_util_LinkedHashMap$sub_refs	java_util_LinkedHashMap;
    _jc_java_util_HashMap$sub_refs	java_util_HashMap;
    _jc_java_util_AbstractMap$sub_refs	java_util_AbstractMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$sub_nonrefs {
	jint	max__5fentries;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap$sub_nonrefs	java_util_AbstractMap;
    _jc_java_util_HashMap$sub_nonrefs	java_util_HashMap;
    _jc_java_util_LinkedHashMap$sub_nonrefs	java_util_LinkedHashMap;
    _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$sub_nonrefs	gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$object {
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$vtype _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkToolkit__24LRUCache_H_ */
